@@ -1,5 +1,5 @@
 use strict;
-use Text::CSV::Base;
+use Text::CSV::Unicode;
 
 my $csv = Text::CSV::Base->new;
 
